[ROCm/clr commit: 6806ab6745]
Этот коммит содержится в:
Evgeny Mankov
2019-05-22 20:04:45 +03:00
родитель 204043c6e0
Коммит a0e1887ff3
+2 -9
Просмотреть файл
@@ -145,12 +145,6 @@ typedef enum hipChannelFormatKind {
#define hipJitOptionFastCompile CU_JIT_FAST_COMPILE
#define hipJitOptionNumOptions CU_JIT_NUM_OPTIONS
// enum CUmemorytype redefines
#define hipMemoryTypeHost CU_MEMORYTYPE_HOST
#define hipMemoryTypeDevice CU_MEMORYTYPE_DEVICE
#define hipMemoryTypeArray CU_MEMORYTYPE_ARRAY
#define hipMemoryTypeUnified CU_MEMORYTYPE_UNIFIED
typedef cudaEvent_t hipEvent_t;
typedef cudaStream_t hipStream_t;
typedef cudaIpcEventHandle_t hipIpcEventHandle_t;
@@ -168,8 +162,7 @@ typedef CUdeviceptr hipDeviceptr_t;
typedef struct cudaArray hipArray;
typedef struct cudaArray* hipArray_const_t;
typedef cudaFuncAttributes hipFuncAttributes;
typedef enum CUmemorytype hipMemoryType;
typedef struct CUDA_MEMCPY2D hip_Memcpy2D;
#define hip_Memcpy2D CUDA_MEMCPY2D
#define hipMemcpy3DParms cudaMemcpy3DParms
#define hipArrayDefault cudaArrayDefault
#define hipArrayLayered cudaArrayLayered
@@ -587,7 +580,7 @@ inline static hipError_t hipMemcpy2D(void* dst, size_t dpitch, const void* src,
}
inline static hipError_t hipMemcpyParam2D(const hip_Memcpy2D* pCopy) {
return hipCUDAErrorTohipError(cuMemcpy2D(hip_Memcpy2D));
return hipCUResultTohipError(cuMemcpy2D(hip_Memcpy2D));
}
inline static hipError_t hipMemcpy3D(const struct hipMemcpy3DParms *p)